==> ola-0.8.33.tar.gz: ola-0.8.33/plugins/karate/KaratePlugin.h <==
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * KaratePlugin.h
 * Interface for the karate plugin class
 * Copyright (C) 2005-2008 Simon Newton
 */

#ifndef PLUGINS_KARATE_KARATEPLUGIN_H_
#define PLUGINS_KARATE_KARATEPLUGIN_H_

#include <string>
#include <vector>
#include "olad/Plugin.h"
#include "ola/plugin_id.h"

namespace ola {
namespace plugin {
namespace karate {

using ola::PluginAdaptor;

class KarateDevice;

class KaratePlugin: public Plugin {
  public:
    explicit KaratePlugin(PluginAdaptor *plugin_adaptor)
        : Plugin(plugin_adaptor) {
    }

    string Name() const { return PLUGIN_NAME; }
    string Description() const;
    ola_plugin_id Id() const { return OLA_PLUGIN_KARATE; }
    string PluginPrefix() const { return PLUGIN_PREFIX; }

  private:
    bool StartHook();
    bool StopHook();
    bool SetDefaultPreferences();

    typedef std::vector<KarateDevice*> DeviceList;
    DeviceList m_devices;

    static const char PLUGIN_NAME[];
    static const char PLUGIN_PREFIX[];
    static const char KARATE_DEVICE_PATH[];
    static const char KARATE_DEVICE_NAME[];
    static const char DEVICE_KEY[];
};
}  // namespace karate
}  // namespace plugin
}  // namespace ola

#endif  // PLUGINS_KARATE_KARATEPLUGIN_H_

==> ola_0.9.0.orig.tar.gz: ola-0.9.0/plugins/karate/KaratePlugin.h <==
/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * KaratePlugin.h
 * Interface for the karate plugin class
 * Copyright (C) 2005-2008 Simon Newton
 */

#ifndef PLUGINS_KARATE_KARATEPLUGIN_H_
#define PLUGINS_KARATE_KARATEPLUGIN_H_

#include <string>
#include <vector>
#include "olad/Plugin.h"
#include "ola/plugin_id.h"

namespace ola {
namespace plugin {
namespace karate {

class KarateDevice;

class KaratePlugin: public Plugin {
 public:
    explicit KaratePlugin(PluginAdaptor *plugin_adaptor)
        : Plugin(plugin_adaptor) {
    }

    std::string Name() const { return PLUGIN_NAME; }
    std::string Description() const;
    ola_plugin_id Id() const { return OLA_PLUGIN_KARATE; }
    std::string PluginPrefix() const { return PLUGIN_PREFIX; }

 private:
    bool StartHook();
    bool StopHook();
    bool SetDefaultPreferences();

    typedef std::vector<KarateDevice*> DeviceList;
    DeviceList m_devices;

    static const char PLUGIN_NAME[];
    static const char PLUGIN_PREFIX[];
    static const char KARATE_DEVICE_PATH[];
    static const char KARATE_DEVICE_NAME[];
    static const char DEVICE_KEY[];
};
}  // namespace karate
}  // namespace plugin
}  // namespace ola

#endif  // PLUGINS_KARATE_KARATEPLUGIN_H_
